summaryrefslogtreecommitdiff
path: root/board/aurash/fw_config.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/aurash/fw_config.c')
-rw-r--r--board/aurash/fw_config.c36
1 files changed, 22 insertions, 14 deletions
diff --git a/board/aurash/fw_config.c b/board/aurash/fw_config.c
index 957a5c8c50..2c312acea6 100644
--- a/board/aurash/fw_config.c
+++ b/board/aurash/fw_config.c
@@ -12,16 +12,16 @@
#define CPRINTS(format, args...) cprints(CC_SYSTEM, format, ##args)
-static union brask_cbi_fw_config fw_config;
+static union aurash_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brask if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brask_cbi_fw_config fw_config_defaults = {
- .audio = DB_NAU88L25B_I2S,
- .bj_power = BJ_135W,
+static const union aurash_cbi_fw_config fw_config_defaults = {
+ .bj_power = BJ_90W,
+ .po_mon = POWER_ON_MONITOR_ENABLE,
};
/*
@@ -31,18 +31,16 @@ static const struct {
int voltage;
int current;
} bj_power[] = {
- [BJ_135W] = { /* 0 - 135W (also default) */
- .voltage = 19500,
- .current = 6920
- },
- [BJ_230W] = { /* 1 - 230W */
- .voltage = 19500,
- .current = 11800
- }
+ [BJ_90W] = { /* 0 - 90W (also default) */
+ .voltage = 19000,
+ .current = 4740 },
+ [BJ_135W] = { /* 1 - 135W */
+ .voltage = 19500,
+ .current = 6920 },
};
/****************************************************************************
- * Brask FW_CONFIG access
+ * Aurash FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -52,6 +50,11 @@ void board_init_fw_config(void)
}
}
+union aurash_cbi_fw_config get_fw_config(void)
+{
+ return fw_config;
+}
+
void ec_bj_power(uint32_t *voltage, uint32_t *current)
{
unsigned int bj;
@@ -63,3 +66,8 @@ void ec_bj_power(uint32_t *voltage, uint32_t *current)
*voltage = bj_power[bj].voltage;
*current = bj_power[bj].current;
}
+
+enum ec_cfg_power_on_monitor ec_cfg_power_on_monitor(void)
+{
+ return fw_config.po_mon;
+}
@@ -12,16 +12,16 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for brask if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for aurash if the CBI.FW_CONFIG data is not
* initialized.
*/